'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _issueActions = require('../actions/issueActions');

var _renderActions = require('../actions/renderActions');

function createState(json, incomingState, repoName) {
  var state = incomingState;
  state.issuesByRepo = {};
  json.filter(function (issue) {
    return !issue.isPR;
  }).forEach(function (issue) {
    state.ids = state.ids.concat(issue.id);
    state.issuesById[issue.id] = {};
    state.issuesById[issue.id].title = issue.title;
    state.issuesById[issue.id].number = issue.number;
    state.issuesById[issue.id].assignedTo = [issue.assignee, issue.assigneeAvatar];
    state.issuesById[issue.id].labels = issue.labels.map(function (label) {
      return label.name;
    });
    if (state.issuesByRepo[repoName]) {
      state.issuesByRepo[repoName] = state.issuesByRepo[repoName].concat(issue.id);
    } else {
      state.issuesByRepo[repoName] = [issue.id];
    }
  });
  return Object.assign({}, state, { loadingIssues: false });
}
var initialState = {
  ids: [],
  issuesById: {},
  loadingIssues: true,
  repoName: ''
};

var issuesReducer = function issuesReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    case _issueActions.GET_ISSUES:
      return createState(action.responseObj, state, action.repoName);
    case _issueActions.LOADING_ISSUES:
      return Object.assign({}, state, {
        loadingIssues: true
      });
    case _renderActions.LOGOUT:
      return initialState;

    default:
      return state;
  }
};

exports.default = issuesReducer;