'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _milestonesActions = require('../actions/milestonesActions');

var _renderActions = require('../actions/renderActions');

function createState(json, incomingState, repoName) {
  var state = incomingState;
  state.milestonesByRepo = {};
  json.forEach(function (milestone) {
    state.ids = state.ids.concat(milestone.id);
    state.milestonesById[milestone.id] = {};
    state.milestonesById[milestone.id].title = milestone.title;
    state.milestonesById[milestone.id].due = milestone.dueOn;
    state.milestonesById[milestone.id].percentComplete = milestone.closedIssues / (milestone.closedIssues + milestone.openIssues);
    if (state.milestonesByRepo[repoName]) {
      state.milestonesByRepo[repoName] = state.milestonesByRepo[repoName].concat(milestone.id);
    } else {
      state.milestonesByRepo[repoName] = [milestone.id];
    }
  });
  return Object.assign({}, state, { loadingMilestones: false });
}
var initialState = {
  ids: [],
  milestonesById: {},
  repoName: ''
};

var milestonesReducer = function milestonesReducer() {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];

  switch (action.type) {
    case _milestonesActions.GET_MILESTONES:
      return createState(action.responseObj, state, action.repoName);
    case _milestonesActions.LOADING_MILESTONES:
      return Object.assign({}, state, {
        loadingMilestones: true
      });
    case _renderActions.LOGOUT:
      return initialState;

    default:
      return state;
  }
};

exports.default = milestonesReducer;